@@ -16,27 +16,68 @@ class Highlight(RestCall):
     _elegance = []
     _apps_full_list = None
     _instance_id = 0
+    _base_url = None
+    _hl_basic_auth = None
+    _hl_user = None
+    _hl_pswd = None
 
     log = None
 
     def __init__(self,  
                  hl_user:str=None, hl_pswd:str=None,hl_basic_auth=None, hl_instance:int=0,
                  hl_apps:str=[],hl_tags:str=[], 
-                 hl_base_url:str='https://rpa.casthighlight.com', 
+                 hl_base_url:str=None, 
                  log_level=INFO, timer_on=False):
 
+        # general message to be used by ValueError exception
+        msg='must be supplied with the first Highlight class instance'
+
         if Highlight.log is None:
+            Highlight._log_level = log_level
             Highlight.log = Logger('Highlight',log_level)
 
         reset_data = False
-        if Highlight._instance_id is not hl_instance:
-            self.log.debug(f'new instance id: {hl_instance}')
+        if Highlight._instance_id == 0:
+            if hl_instance == 0:
+                raise ValueError(f'Domain id {msg}') 
+
             Highlight._instance_id = hl_instance
             Highlight._data = {}
             reset_data = True
+        
+        #set the base url, if not already set from a prev instance of the Highlight class
+        if Highlight._base_url is None:
+            if hl_base_url is None:
+                raise ValueError(f'Base url {msg}') 
 
-        super().__init__(base_url=f'{hl_base_url}/WS2/', user=hl_user, password=hl_pswd, 
-                         basic_auth=hl_basic_auth,track_time=timer_on,log_level=log_level)
+            Highlight._base_url = hl_base_url
+            if Highlight._base_url.endswith('/'):
+                Highlight._base_url=Highlight._base_url[:-1]
+                            
+            if not Highlight._base_url.endswith('/WS2'):
+                Highlight._base_url=f'{Highlight._base_url}/WS2/'
+
+        #set the user name/password or Basic Autorization 
+        if Highlight._hl_basic_auth is None and \
+            Highlight._hl_user is None and \
+            Highlight._hl_pswd is None:
+
+            if hl_user is None and \
+                hl_pswd is None and \
+                hl_basic_auth is None:
+                raise ValueError(f'UserName/password or Basic Authorization {msg}')
+
+            if not hl_user is None:
+                Highlight._hl_user=hl_user
+
+            if not hl_pswd is None:
+                Highlight._hl_pswd=hl_pswd
+
+            if not hl_basic_auth is None:
+                Highlight._hl_basic_auth=hl_basic_auth
+
+        super().__init__(base_url=Highlight._base_url, user=Highlight._hl_user, password=Highlight._hl_pswd, 
+                         basic_auth=Highlight._hl_basic_auth,track_time=timer_on,log_level=Highlight._log_level)
 
         # self._business = self._get_top_metric('businessValue')
         # self._cloud = self._get_top_metric('cloudValue')
@@ -52,17 +93,18 @@ class Highlight(RestCall):
 #            Highlight._apps_full_list.dropna(subset=['metrics'],inplace=True)
             self.info(f'Found {len(Highlight._apps_full_list)} analyzed applications: {",".join(Highlight._apps_full_list["name"])}')
     
-        # if the apps is not already of list type then convert it now
-        if not isinstance(hl_apps,list):
-            hl_apps=list(hl_apps.split(','))
+            # if the apps is not already of list type then convert it now
+            if not isinstance(hl_apps,list):
+                hl_apps=list(hl_apps.split(','))
 
-        #if hl_apps is empty, include all applications prevously retrieved
-        #otherwise filter the list down to include only the selected applications
-        if len(hl_apps) > 0:
-            self._apps = Highlight._apps_full_list[Highlight._apps_full_list['name'].isin(hl_apps)]
-        else:
-            self._apps = Highlight._apps_full_list
+            #if hl_apps is empty, include all applications prevously retrieved
+            #otherwise filter the list down to include only the selected applications
+            if len(hl_apps) > 0:
+                self._apps = Highlight._apps_full_list[Highlight._apps_full_list['name'].isin(hl_apps)]
+            else:
+                self._apps = Highlight._apps_full_list
 
+            if self._apps is not None:
         self.info(f'{len(self._apps)} applications selected: {",".join(self._apps["name"])}')
 
         pass
